@@ -13,8 +13,11 @@ module Network.TLS.Extra
 	, module Network.TLS.Extra.Certificate
 	-- * Connection helpers
 	, module Network.TLS.Extra.Connection
+	-- * File helpers
+	, module Network.TLS.Extra.File
 	) where
 
 import Network.TLS.Extra.Cipher
 import Network.TLS.Extra.Certificate
 import Network.TLS.Extra.Connection
+import Network.TLS.Extra.File
